@@ -26,19 +26,16 @@ def cmd():
     elif args[-1] == "query":
         status = os.system("curl http://"+get_ip()+":8080/query")
     elif args[-1] == "notify":
-        status = os.system("curl http://"+get_ip()+":8080/query")
+        notify()
     else:
-        print("Usage: ids [(Null)|gpu|top|topall]")
+        print("Usage: ids [(Null)|top|topall|notify|query|gpu]")
 
 
 def gpu():
-    print("Do you really want to notify other users to free up GPU resources? (y/n)")
-    ans = input()
-    if ans == "y":
-        status = os.system("curl http://"+get_ip()+":8080/gpu_notify")
+    notify()
 
 def notify():
-    print("Do you really want to notify other users to free up GPU resources? (y/n)")
+    print("Do you really want to notify other users to free up GPU resources? (y/n): ", end="")
     ans = input()
     if ans == "y":
         status = os.system("curl http://"+get_ip()+":8080/gpu_notify")
@@ -54,3 +51,6 @@ def topall():
 
 def query():
     status = os.system("curl http://"+get_ip()+":8080/query")
+
+if __name__ == "__main__":
+    cmd()
\ No newline at end of file
